pub struct RunModeContext {
pub a: i32,
pub n: i32,
pub nn: i32,
pub ri_type: i32,
pub reset: i32,
}Expand description
Context for run-interruption mode.
When the codec detects a run of identical pixels and the run ends, it uses a separate set of statistics for coding the interruption sample.
Fields
a: i32Accumulated |error|.
n: i32Sample count.
nn: i32Count of negative errors (used for map).
ri_type: i32Run interruption type (0 or 1).
reset: i32Reset threshold.
Implementations
Sourceimpl RunModeContext
impl RunModeContext
pub fn new(a_init: i32, reset: i32) -> Self
Sourcepub fn get_golomb(&self) -> i32
pub fn get_golomb(&self) -> i32
Compute Golomb parameter for run interruption.
Sourcepub fn compute_map(&self, err_val: i32, k: i32) -> i32
pub fn compute_map(&self, err_val: i32, k: i32) -> i32
Compute the map value (whether to add 1 to the mapped error).
Sourcepub fn compute_map_negative_e(&self, k: i32) -> bool
pub fn compute_map_negative_e(&self, k: i32) -> bool
Compute the mapped error value for Golomb-Rice coding.
Sourcepub fn update_variables(&mut self, err_val: i32, e_mapped: i32)
pub fn update_variables(&mut self, err_val: i32, e_mapped: i32)
Update run-mode statistics after coding an error.