pub struct CodecRegistry { /* private fields */ }Expand description
Registry of all available image codecs, keyed by transfer syntax UID.
Implementations
Sourceimpl CodecRegistry
impl CodecRegistry
Sourcepub fn register(&self, codec: Arc<dyn ImageCodec>)
pub fn register(&self, codec: Arc<dyn ImageCodec>)
Register a codec (replaces any existing codec for the same UID).
Sourcepub fn find(&self, transfer_syntax_uid: &str) -> Option<Arc<dyn ImageCodec>>
pub fn find(&self, transfer_syntax_uid: &str) -> Option<Arc<dyn ImageCodec>>
Look up a codec that supports both decoding and encoding for a transfer syntax UID.
Sourcepub fn find_decoder(
&self,
transfer_syntax_uid: &str,
) -> Option<Arc<dyn ImageCodec>>
pub fn find_decoder( &self, transfer_syntax_uid: &str, ) -> Option<Arc<dyn ImageCodec>>
Look up a decoder by transfer syntax UID.
Sourcepub fn find_encoder(
&self,
transfer_syntax_uid: &str,
) -> Option<Arc<dyn ImageCodec>>
pub fn find_encoder( &self, transfer_syntax_uid: &str, ) -> Option<Arc<dyn ImageCodec>>
Look up an encoder by transfer syntax UID.
Sourcepub fn find_required(
&self,
transfer_syntax_uid: &str,
) -> DcmResult<Arc<dyn ImageCodec>>
pub fn find_required( &self, transfer_syntax_uid: &str, ) -> DcmResult<Arc<dyn ImageCodec>>
Look up a codec that supports both decoding and encoding or return a
DcmError::NoCodec error.
Sourcepub fn find_decoder_required(
&self,
transfer_syntax_uid: &str,
) -> DcmResult<Arc<dyn ImageCodec>>
pub fn find_decoder_required( &self, transfer_syntax_uid: &str, ) -> DcmResult<Arc<dyn ImageCodec>>
Look up a decoder or return a DcmError::NoCodec error.
Sourcepub fn find_encoder_required(
&self,
transfer_syntax_uid: &str,
) -> DcmResult<Arc<dyn ImageCodec>>
pub fn find_encoder_required( &self, transfer_syntax_uid: &str, ) -> DcmResult<Arc<dyn ImageCodec>>
Look up an encoder or return a DcmError::NoCodec error.